a.treeviewLink48 {
color:#000;
cursor:pointer;
font-family:verdana,sans-serif;
font-size:46px;
height:66px;
vertical-align:top;
}
a.treeviewLink48:hover {
color:blue;
cursor:pointer;
font-family:verdana,sans-serif;
font-size:46px;
height:66px;
vertical-align:top;
}
table.treeview48 {
background-color:#FFF;
color:#000;
}
td.captionBorder48 {
border-bottom:1px;
border-bottom-style:dashed;
color:#000;
font-family:verdana, sans-serif;
font-size:46px;
height:66px;
vertical-align:top;
white-space:nowrap;
}
td.clasicLastMinusNode48 {
background-image:url('/style/Crystal/48/html-menu-treeview/clasicLastMinusNode.gif');
background-repeat:no-repeat;
cursor:pointer;
height:66px;
vertical-align:top;
}
td.clasicLastPlusNode48 {
background-image:url('/style/Crystal/48/html-menu-treeview/clasicLastPlusNode.gif');
background-repeat:no-repeat;
cursor:pointer;
height:66px;
vertical-align:top;
}
td.clasicMinusNode48 {
background-image:url('/style/Crystal/48/html-menu-treeview/clasicMinusNode.gif');
background-repeat:no-repeat;
cursor:pointer;
vertical-align:top;
}
td.clasicPlusNode48 {
background-image:url('/style/Crystal/48/html-menu-treeview/clasicPlusNode.gif');
background-repeat:no-repeat;
cursor:pointer;
height:66px;
vertical-align:top;
}
td.columnsFolder48,td.columnsNode48,td.caption48 {
font-family:verdana, sans-serif;
font-size:46px;
height:66px;
white-space:nowrap;
vertical-align:top;
}
td.columnsFolderBorder48,td.columnsNodeBorder48,td.columnsLastNodeBorder48 {
border-left:1px;
border-left-style:dashed;
color:#000;
font-family:verdana, sans-serif;
font-size:46px;
height:66px;
vertical-align:top;
white-space:nowrap;
}
td.columnsLastNode48 {
font-family:verdana, sans-serif;
font-size:46px;
height:66px;
white-space:nowrap;
}
td.folder48 {
background-image:url('/style/Crystal/48/html-menu-treeview/folderOpen.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:46px;
height:66px;
vertical-align:top;
}
td.folderClosed48 {
background-image:url('/style/Crystal/48/html-menu-treeview/folderClosed.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:46px;
height:66px;
vertical-align:top;
}
td.folderCrystal48 {
background-image:url('/style/Crystal/48/html-menu-treeview/folderCrystal.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:46px;
height:66px;
vertical-align:top;
}
td.folderCrystalClosed48 {
background-image:url('/style/Crystal/48/html-menu-treeview/folderCrystalClosed.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:46px;
height:66px;
vertical-align:top;
}
td.folderFavorite48 {
background-image:url('/style/Crystal/48/html-menu-treeview/folderFavorite.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:46px;
height:66px;
vertical-align:top;
}
td.folderFavoriteClosed48 {
background-image:url('/style/Crystal/48/html-menu-treeview/folderFavoriteClosed.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:46px;
height:66px;
vertical-align:top;
}
td.folderGray48 {
background-image:url('/style/Crystal/48/html-menu-treeview/folderGray.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:46px;
height:66px;
vertical-align:top;
}
td.folderGrayClosed48 {
background-image:url('/style/Crystal/48/html-menu-treeview/folderGrayClosed.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:46px;
height:66px;
vertical-align:top;
}
td.folderGreen48 {
background-image:url('/style/Crystal/48/html-menu-treeview/folderGreen.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:46px;
height:66px;
vertical-align:top;
}
td.folderGreenClosed48 {
background-image:url('/style/Crystal/48/html-menu-treeview/folderGreenClosed.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:46px;
height:66px;
vertical-align:top;
}
td.folderHtml48 {
background-image:url('/style/Crystal/48/html-menu-treeview/folderHtml.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:46px;
height:66px;
vertical-align:top;
}
td.folderHtmlClosed48 {
background-image:url('/style/Crystal/48/html-menu-treeview/folderHtmlClosed.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:46px;
height:66px;
vertical-align:top;
}
td.folderImage48 {
background-image:url('/style/Crystal/48/html-menu-treeview/folderImage.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:46px;
height:66px;
vertical-align:top;
}
td.folderImageClosed48 {
background-image:url('/style/Crystal/48/html-menu-treeview/folderImageClosed.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:46px;
height:66px;
vertical-align:top;
}
td.folderImportant48 {
background-image:url('/style/Crystal/48/html-menu-treeview/folderImportant.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:46px;
height:66px;
vertical-align:top;
}
td.folderImportantClosed48 {
background-image:url('/style/Crystal/48/html-menu-treeview/folderImportantClosed.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:46px;
height:66px;
vertical-align:top;
}
td.folderLocked48 {
background-image:url('/style/Crystal/48/html-menu-treeview/folderLocked.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:46px;
height:66px;
vertical-align:top;
}
td.folderLockedClosed48 {
background-image:url('/style/Crystal/48/html-menu-treeview/folderLockedClosed.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:46px;
height:66px;
vertical-align:top;
}
td.folderMan48 {
background-image:url('/style/Crystal/48/html-menu-treeview/folderMan.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:46px;
height:66px;
vertical-align:top;
}
td.folderManClosed48 {
background-image:url('/style/Crystal/48/html-menu-treeview/folderManClosed.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:46px;
height:66px;
vertical-align:top;
}
td.folderOrange48 {
background-image:url('/style/Crystal/48/html-menu-treeview/folderOrange.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:46px;
height:66px;
vertical-align:top;
}
td.folderOrangeClosed48 {
background-image:url('/style/Crystal/48/html-menu-treeview/folderOrangeClosed.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:46px;
height:66px;
vertical-align:top;
}
td.folderPrint48 {
background-image:url('/style/Crystal/48/html-menu-treeview/folderPrint.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:46px;
height:66px;
vertical-align:top;
}
td.folderPrintClosed48 {
background-image:url('/style/Crystal/48/html-menu-treeview/folderPrintClosed.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:46px;
height:66px;
vertical-align:top;
}
td.folderRed48 {
background-image:url('/style/Crystal/48/html-menu-treeview/folderRed.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:46px;
height:66px;
vertical-align:top;
}
td.folderRedClosed48 {
background-image:url('/style/Crystal/48/html-menu-treeview/folderRedClosed.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:46px;
height:66px;
vertical-align:top;
}
td.folderSound48 {
background-image:url('/style/Crystal/48/html-menu-treeview/folderSound.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:46px;
height:66px;
vertical-align:top;
}
td.folderSoundClosed48 {
background-image:url('/style/Crystal/48/html-menu-treeview/folderSoundClosed.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:46px;
height:66px;
vertical-align:top;
}
td.folderTar48 {
background-image:url('/style/Crystal/48/html-menu-treeview/folderTar.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:46px;
height:66px;
vertical-align:top;
}
td.folderTarClosed48 {
background-image:url('/style/Crystal/48/html-menu-treeview/folderTarClosed.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:46px;
height:66px;
vertical-align:top;
}
td.folderText48 {
background-image:url('/style/Crystal/48/html-menu-treeview/folderText.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:46px;
height:66px;
vertical-align:top;
}
td.folderTextClosed48 {
background-image:url('/style/Crystal/48/html-menu-treeview/folderTextClosed.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:46px;
height:66px;
vertical-align:top;
}
td.folderVideo48 {
background-image:url('/style/Crystal/48/html-menu-treeview/folderVideo.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:46px;
height:66px;
vertical-align:top;
}
td.folderVideoClosed48 {
background-image:url('/style/Crystal/48/html-menu-treeview/folderVideoClosed.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:46px;
height:66px;
vertical-align:top;
}
td.folderViolet48 {
background-image:url('/style/Crystal/48/html-menu-treeview/folderViolet.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:46px;
height:66px;
vertical-align:top;
}
td.folderVioletClosed48 {
background-image:url('/style/Crystal/48/html-menu-treeview/folderVioletClosed.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:46px;
height:66px;
vertical-align:top;
}
td.folderYellow48 {
background-image:url('/style/Crystal/48/html-menu-treeview/folderYellow.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:46px;
height:66px;
vertical-align:top;
}
td.folderYellowClosed48 {
background-image:url('/style/Crystal/48/html-menu-treeview/folderYellowClosed.gif');
background-repeat:no-repeat;
color:#000;
cursor:pointer;
font-size:46px;
height:66px;
vertical-align:top;
}
td.lastMinusNode48 {
background-image:url('/style/Crystal/48/html-menu-treeview/lastMinusNode.gif');
background-repeat:no-repeat;
cursor:pointer;
vertical-align:top;
}
td.lastNode48 {
background-image:url('/style/Crystal/48/html-menu-treeview/lastNode.gif');
background-repeat:no-repeat;
cursor:pointer;
font-size:46px;
height:66px;
vertical-align:top;
}
td.lastPlusNode48 {
background-image:url('/style/Crystal/48/html-menu-treeview/lastPlusNode.gif');
background-repeat:no-repeat;
cursor:pointer;
height:66px;
vertical-align:top;
}
td.minusNode48 {
background-image:url('/style/Crystal/48/html-menu-treeview/minusNode.gif');
background-repeat:no-repeat;
cursor:pointer;
vertical-align:top;
}
td.node48 {
background-image:url('/style/Crystal/48/html-menu-treeview/node.gif');
background-repeat:repeat-y;
cursor:pointer;
font-size:46px;
height:66px;
text-align:left;
vertical-align:top;
}
td.plusNode48 {
background-image:url('/style/Crystal/48/html-menu-treeview/plusNode.gif');
background-repeat:no-repeat;
cursor:pointer;
vertical-align:top;
}
td.submenuDeco48 {
background-image:url('/style/Crystal/48/html-menu-treeview/vertLine.gif');
background-repeat:repeat-y;
}